@@ -1695,8 +1695,11 @@ class Template(Query):
             if not con.editable:
                 raise ConstraintError("There is a constraint '" + code 
                                        + "' on this query, but it is not editable")
-            for key, value in options.items():
-                setattr(con, key, value)
+            try:
+                for key, value in options.items():
+                    setattr(con, key, value)
+            except AttributeError:
+                setattr(con, "value", options)
         return clone
 
     def results(self, row="object", start=0, size=None, **con_values):
